summaryrefslogtreecommitdiffstats
path: root/Utilities/cmcurl/lib/sigpipe.h
diff options
context:
space:
mode:
Diffstat (limited to 'Utilities/cmcurl/lib/sigpipe.h')
-rw-r--r--Utilities/cmcurl/lib/sigpipe.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/Utilities/cmcurl/lib/sigpipe.h b/Utilities/cmcurl/lib/sigpipe.h
index e8d2acd..800f9d3 100644
--- a/Utilities/cmcurl/lib/sigpipe.h
+++ b/Utilities/cmcurl/lib/sigpipe.h
@@ -11,7 +11,7 @@
*
* This software is licensed as described in the file COPYING, which
* you should have received as part of this distribution. The terms
- * are also available at http://curl.haxx.se/docs/copyright.html.
+ * are also available at https://curl.haxx.se/docs/copyright.html.
*
* You may opt to use, copy, modify, merge, publish, distribute and/or sell
* copies of the Software, and permit persons to whom the Software is
@@ -38,10 +38,10 @@ struct sigpipe_ignore {
* internals, and then sigpipe_restore() will restore the situation when we
* return from libcurl again.
*/
-static void sigpipe_ignore(struct SessionHandle *data,
+static void sigpipe_ignore(struct Curl_easy *data,
struct sigpipe_ignore *ig)
{
/* get a local copy of no_signal because the SessionHandle might not be
around when we restore */
ig->no_signal = data->set.no_signal;
if(!data->set.no_signal) {
@@ -38,10 +38,10 @@ struct sigpipe_ignore {
struct sigpipe_ignore *ig)
{
- /* get a local copy of no_signal because the SessionHandle might not be
+ /* get a local copy of no_signal because the Curl_easy might not be
around when we restore */
ig->no_signal = data->set.no_signal;